Learn R Programming

Mirsynergy (version 1.8.1)

mirsynergy: Detect synergistic miRNA regulatory modules by overlapping neighbourhood expansion

Description

Detect synergistic miRNA regulatory modules by overlapping neighbourhood expansion using a deterministic overlapping clustering algorithm adapted from a recently developed framework. Mirsynergy operates in two stages that first forms MRM based on co-occurring miRNAs and then expand the MRM by greedily including (excluding) mRNA into (from) the MRM to maximize the synergy score, which is a function of miRNA-mRNA and gene-gene interactions.

Usage

mirsynergy(W, H, alpha = 2, merge.tol = 0.8, density1.tol = 1e-2, density2.tol=5e-3, verbose = FALSE)

Arguments

W
An N by M edge weight matrix containing interaction strength between N mRNA and M miRNA.
H
An N by N edge weight matrix containing the binary interaction among the N mRNA (genes).
alpha
Penalty for including a node into the growing module (advanced option). See manuscript or Nepusz et al. (2012) for more details.
merge.tol
Threshold with range [0,1] to merge modules based on the percentage of nodes shared between the two modules.
density1.tol
Threshold with range [0,1] to filter modules by the density function at stage 1 clustering.
density2.tol
Threshold with range [0,1] to filter modules by the density function 2 at stage 2 clustering.
verbose
Binary indicator to show running info.

Value

A nested list containing each item as a miRNA regulatory module (MRM). Each item itself is a list containing the following information:
miRNA
miRNA included in the MRM
mRNA
mRNA included in the MRM
v.in
miRNA and mRNA
v.bound
miRNA and mRNA disregard or excluded from the MRM but still have nonzero connection with the internal nodes
card.m
Number of miRNA in the MRM
card.t
Number of mRNA targets in the MRM
card
Total number of miRNA and mRNA targets in the MRM
density
Density of the MRM

Details

The weight matrix W can be obtained by various approaches such as Pearson correlation or linear regression on mRNA and miNRA expression profiles across multiple samples. Matrix H can be obtained from public database such as TRANSFAC and BioGrid.

References

Nepusz, T., Yu, H., & Paccanaro, A. (2012). Detecting overlapping protein complexes in protein-protein interaction networks. Nature Methods, 9(5), 471-472. doi:10.1038/nmeth.1938

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.
##
# simulate N mRNA and M miRNA and their interaction matrices
load(system.file("extdata/toy_modules.RData", package="Mirsynergy"))

# run mirsynergy clustering
V <- mirsynergy(W, H, verbose=TRUE)

summary_modules(V)

Run the code above in your browser using DataLab