| Package: |
| Mirsynergy |
| Type: |
| Package |
| Version: |
| 0.99.2 |
| Date: |
| 2014-02-06 |
| License: |
| GPL-2 |
mirsynergy takes as inputs the mRNA and miRNA
interaction matrix and gene-gene interaction matrix provided by the user or
generated from existing techniques described in the manuscript (in preparation).
The function then outputs a list with each item as a miRNA regulatory module
(MRM) containing miRNA and mRNA ID and and other results for diagnostic purpose.
Nepusz, T., Yu, H., & Paccanaro, A. (2012). Detecting overlapping protein complexes in protein-protein interaction networks. Nature Methods, 9(5), 471-472. doi:10.1038/nmeth.1938
mirsynergy